@@ -20,7 +20,7 @@ from dnoticias_services.authentication.keycloak import get_user_keycloak_info
 from mozilla_django_oidc.utils import absolutify, import_from_settings
 from mozilla_django_oidc.auth import OIDCAuthenticationBackend
 
-from .utils import set_cookie, get_cookie_configuration, SessionManager
+from .utils import set_cookie, SessionManager
 from . import cookies_consts
 
 User = get_user_model()
@@ -92,21 +92,6 @@ class BaseAuthMiddleware:
 
         return exempt_patterns
 
-    @cached_property
-    def exempt_session_url_patterns(self) -> set:
-        """Urls that should not be processed by this middleware in DCS password update session
-
-        :return: set of regular expressions
-        :rtype: set"""
-        exempt_patterns = set()
-        patterns = getattr(settings, "SESSION_CHECK_EXEMPT_URLS", [])
-
-        for url_pattern in patterns:
-            if isinstance(url_pattern, Pattern):
-                exempt_patterns.add(url_pattern)
-
-        return exempt_patterns 
-
     def _is_processable(self, request: HttpRequest):
         pass
 
@@ -239,15 +224,21 @@ class TokenMiddleware(BaseAuthMiddleware, MiddlewareMixin):
             old_keycloak_session_value = request.session.get('old_keycloak_session_id', '')
 
             response = set_cookie(oidc_login_cookie, oidc_login_value, response)
-            response = set_cookie(access_token_cookie, access_token_value, response)
+            response = set_cookie(access_token_cookie, access_token_value, response, http_only=True)
             response = set_cookie(
                 access_token_expiration_cookie,
                 access_token_expiration_value,
-                response
+                response,
+                http_only=True
             )
 
             if keycloak_session_value:
-                response = set_cookie(keycloak_session_cookie, keycloak_session_value, response)
+                response = set_cookie(
+                    keycloak_session_cookie,
+                    keycloak_session_value,
+                    response,
+                    http_only=True
+                )
 
             if old_keycloak_session_value != keycloak_session_value:
                 request.session["old_keycloak_session_value"] = keycloak_session_value
@@ -263,6 +254,11 @@ class TokenMiddleware(BaseAuthMiddleware, MiddlewareMixin):
                 request.session.save()
 
             if old_keycloak_session_value:
-                response = set_cookie(old_keycloak_session_cookie, old_keycloak_session_value, response)
+                response = set_cookie(
+                    old_keycloak_session_cookie,
+                    old_keycloak_session_value,
+                    response,
+                    http_only=True
+                )
 
         return response
