@@ -23,4 +23,9 @@ urlpatterns = [
         views.ApplicationDataView.as_view(),
         name="application-data"
     ),
+    path(
+        "endpoints/logout/",
+        views.DnoticiasLogoutEndpointView.as_view(),
+        name="dnoticias-logout-endpoint"
+    )
 ]
