@@ -1,24 +1,25 @@
 import logging
+from urllib.parse import urljoin
 from time import time
 
 from django.views.decorators.clickjacking import xframe_options_exempt
 from django.core.exceptions import SuspiciousOperation
 from django.http.response import HttpResponseRedirect
+from django.utils.module_loading import import_string
 from django.views.decorators.csrf import csrf_exempt
 from django.utils.decorators import method_decorator
-from django.views.generic import View, FormView
 from django.http import Http404, HttpResponse
-from django.urls import reverse_lazy
+from django.views.generic import View
 from django.shortcuts import render
 from django.conf import settings
 from django.contrib import auth
 
+import requests
 from mozilla_django_oidc.views import (
     OIDCLogoutView,
     OIDCAuthenticationCallbackView
 )
 
-from .forms import PasswordRecoveryDCSForm
 from . import cookies_consts
 from .utils import (
     SessionManager,
@@ -26,6 +27,7 @@ from .utils import (
     delete_oidc_cookies,
     delete_user_sessions,
     refresh_keycloak_token,
+    INTERNAL_CLIENTS_KEY_HEADER
 )
 
 logger = logging.getLogger(__name__)
@@ -77,6 +79,34 @@ class DnoticiasOIDCLogoutView(OIDCLogoutView):
             logger.warning("No BASE_URL configured! Using / as default...")
 
         return logout_url + next_url if logout_url else base_url
+    
+    def trigger_logout_endpoints(self, request):
+        """
+        This function was created to trigger the logout endpoints of the other services
+        """
+        logout_endpoints = self.get_settings('AUTH_INTERNAL_CLIENTS_URLS', None)
+        logout_endpoints_keys = self.get_settings('AUTH_INTERNAL_CLIENTS_SECRETS', None)
+        logout_path = self.get_settings('AUTH_LOGOUT_ENDOPINT_PATH', '/auth/endpoints/logout/')
+
+        logger.debug("Logout endpoints: %s", logout_endpoints)
+        if logout_endpoints:
+            for index, endpoint in enumerate(logout_endpoints):
+                endpoint = urljoin(endpoint, logout_path)
+
+                try:
+                    response = requests.post(
+                        endpoint,
+                        data={
+                            "email": request.user.email,
+                        },
+                        headers={
+                            INTERNAL_CLIENTS_KEY_HEADER: logout_endpoints_keys[index],
+                        },
+                        cookies=request.COOKIES,
+                    )
+                    response.raise_for_status()
+                except Exception as e:
+                    logger.exception("Error while trying to logout from %s", endpoint)
 
     def post(self, request) -> HttpResponseRedirect:
         """
@@ -97,11 +127,38 @@ class DnoticiasOIDCLogoutView(OIDCLogoutView):
         )
 
         delete_user_sessions(keycloak_session_id)
+        self.trigger_logout_endpoints(request)
         super().post(request)
 
         return delete_oidc_cookies(self.redirect_url, request.COOKIES)
 
 
+class DnoticiasLogoutEndpointView(View):
+    @method_decorator(csrf_exempt)
+    def dispatch(self, request, *args, **kwargs):
+        return super().dispatch(request, *args, **kwargs)
+
+    def post(self, request):
+        """This endpoint is used to logout from the other services"""
+        logout_function = getattr(settings, "AUTH_LOGOUT_ENDPOINT_FUNCTION", None)
+        internal_secret = getattr(settings, "AUTH_INTERNAL_CLIENT_SECRET", None)
+
+        if not internal_secret or not logout_function:
+            raise Http404()
+
+        if request.headers.get(INTERNAL_CLIENTS_KEY_HEADER) != internal_secret:
+            raise HttpResponse(status=403)
+
+        email = request.POST.get("email")
+        cookies = request.COOKIES
+
+        if logout_function:
+            logout_function = import_string(logout_function)
+            logout_function(email, cookies)
+
+        return HttpResponse(status=204)
+
+
 class DnoticiasOIDCAuthenticationCallbackView(OIDCAuthenticationCallbackView):
     def login_failure(self, delete_cookies: bool = False) -> HttpResponse:
         response = HttpResponseRedirect(self.failure_url)
@@ -121,11 +178,12 @@ class DnoticiasOIDCAuthenticationCallbackView(OIDCAuthenticationCallbackView):
         access_token_expiration_cookie = cookies_consts.ACCESS_TOKEN_EXPIRATION
         access_token_cookie = cookies_consts.ACCESS_TOKEN
 
-        response = set_cookie(access_token_cookie, access_token, response)
+        response = set_cookie(access_token_cookie, access_token, response, http_only=True)
         response = set_cookie(
             access_token_expiration_cookie,
             access_token_expiration,
-            response
+            response,
+            http_only=True
         )
 
         return response
@@ -217,38 +275,3 @@ class ApplicationDataView(View):
         refresh_token_expires_in = request.session.get("oidc_refresh_expires_in")
 
         return render(request, self.template_name, locals())
-
-
-class PasswordRecoveryDCSFormView(FormView):
-    template_name = "authentication/password-recovery.html"
-    form_class = PasswordRecoveryDCSForm
-
-    def dispatch(self, request, *args, **kwargs):
-        if not request.session.get("migration_email"):
-            raise Http404()
-
-        return super().dispatch(request, *args, **kwargs)
-
-    def get_success_url(self):
-        next_url = self.request.session.get("migration_next_url")
-        login_url = reverse_lazy("oidc_authentication_init")
-        return f"{login_url}?next_url={next_url}"
-
-    def get_context_data(self, **kwargs) -> dict:
-        context = super().get_context_data(**kwargs)
-        next_url = self.request.session.get('migration_next_url')
-        reset_url = settings.OIDC_RESET_PASSWORD_URL
-        context["password_recovery_url"] = f"{reset_url}?next={next_url}"
-        return context
-
-    def get_form_kwargs(self) -> dict:
-        kwargs = super().get_form_kwargs()
-        kwargs["email"] = self.request.session.get("migration_email")
-        return kwargs
-
-    def form_valid(self, form):
-        form.save()
-        return super().form_valid(form)
-
-    def form_invalid(self, form):
-        return super().form_invalid(form)
